@@ -1,47 +1,50 @@
-## ----setup, include = FALSE----------------------------------------------
+## ----setup, include = FALSE---------------------------------------------------
 library("leiden")
 library("reticulate")
 py_available()
 module <- py_available() && py_numpy_available() && py_module_available("leidenalg") && py_module_available("igraph")
-if(module){
-  py_config()$python
-  py_install("numpy")
-  py_install("scipy")
-  py_install("python-igraph")
-  py_install("leidenalg")
-  module <- py_module_available("leidenalg") && py_module_available("igraph")
-}
+# if(module){
+#   reticulate::install_miniconda()
+#   py_config()$python
+#   reticulate::conda_create("r-reticulate")
+#   reticulate::use_condaenv("r-reticulate")
+#   conda_install("r-reticulate", "numpy")
+#   conda_install("r-reticulate", "scipy")
+#   reticulate::conda_install("r-reticulate", "python-igraph")
+#   reticulate::py_install("r-reticulate", "leidenalg")
+#   module <- py_module_available("leidenalg") && py_module_available("igraph")
+# }
 if(module){
   leidenalg <- import("leidenalg", delay_load = TRUE)
   ig <- import("igraph", delay_load = TRUE)
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
   eval = module
 )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 print(module)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 paste(Sys.info()[c(4, 2, 1)])
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 R.version$version.string
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  library("reticulate")
 #  py_install("python-igraph")
 #  py_install("leidenalg")
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 partition <- py$partition$membership + 1
 table(partition)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library("igraph")
 library("reticulate")
 library("RColorBrewer")
@@ -49,28 +52,28 @@ graph_object <- graph.famous("Zachary")
 node.cols <- brewer.pal(max(c(3, partition)),"Pastel1")[partition]
 plot(graph_object, vertex.color = node.cols, layout=layout_with_kk)
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 partition <- py$partition$membership + 1
 table(partition)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 graph_object <- graph.famous("Zachary")
 node.cols <- brewer.pal(max(c(3, partition)),"Pastel1")[partition]
 plot(graph_object, vertex.color = node.cols, layout=layout_with_kk)
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 partition <- py$partition$membership + 1
 table(partition)
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 graph_object <- graph.famous("Zachary")
 node.cols <- brewer.pal(max(c(3, partition)),"Pastel1")[partition]
 plot(graph_object, vertex.color = node.cols, layout=layout_with_kk)
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 bash_py_time <- as.numeric(readLines("bash_py_time"))
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 leidenalg <- import("leidenalg", delay_load = TRUE)
 ig <- import("igraph", delay_load = TRUE)
 G = ig$Graph$Famous('Zachary')
@@ -78,7 +81,7 @@ G$summary()
 partition = leidenalg$find_partition(G, leidenalg$ModularityVertexPartition)
 partition$membership
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 leidenalg <- import("leidenalg", delay_load = TRUE)
 ig <- import("igraph", delay_load = TRUE)
 G = ig$Graph$Famous('Zachary')
@@ -92,57 +95,61 @@ partition$membership
 reticulate_time <- difftime(end, start)[[1]]
 print(paste(c("leiden time:", reticulate_time, "seconds"), collapse = " "))
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  install.packages("leiden")
 
-## ------------------------------------------------------------------------
+## ---- eval=TRUE, include=FALSE------------------------------------------------
+install.packages("leiden",  quiet = TRUE, repos = 1)
+devtools::install_github("TomKellyGenetics/leiden", ref = "dev")
+
+## -----------------------------------------------------------------------------
 R.version.string
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library("igraph")
 library("leiden")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 G <- graph.famous("Zachary")
 summary(G)
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 partition <- leiden(G, "ModularityVertexPartition")
 partition
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 table(partition)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library("igraph")
 library("reticulate")
 library("RColorBrewer")
 node.cols <- brewer.pal(max(c(3, partition)),"Pastel1")[partition]
 plot(G, vertex.color = node.cols, layout=layout_with_kk)
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 partition <- leiden(G, "CPMVertexPartition", resolution_parameter = 0.5)
 partition
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 table(partition)
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 node.cols <- brewer.pal(max(c(3, partition)),"Pastel1")[partition]
 plot(G, vertex.color = node.cols, layout=layout_with_kk)
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 partition <- leiden(G, "RBConfigurationVertexPartition", resolution_parameter = 1.5)
 partition
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 table(partition)
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 node.cols <- brewer.pal(max(c(3, partition)),"Pastel1")[partition]
 plot(G, vertex.color = node.cols, layout=layout_with_kk)
 
-## ---- cache=TRUE---------------------------------------------------------
+## ---- cache=TRUE, , eval=module-----------------------------------------------
 G <- graph.famous('Zachary')
 summary(G)
 start <- Sys.time()
@@ -154,7 +161,7 @@ table(partition)
 R_graph_time = difftime(end, start)[[1]]
 print(paste(c("leiden time:", R_graph_time, "seconds"), collapse = " "))
 
-## ---- cache=TRUE---------------------------------------------------------
+## ---- cache=TRUE, eval=module-------------------------------------------------
 G <- graph.famous('Zachary')
 summary(G)
 
@@ -176,7 +183,7 @@ table(partition)
 R_mat_time = difftime(end, start)[[1]]
 print(paste(c("leiden time:", R_mat_time, "seconds"), collapse = " "))
 
-## ---- cache=TRUE---------------------------------------------------------
+## ---- cache=TRUE, eval=module-------------------------------------------------
 G <- graph.famous('Zachary')
 summary(G)
 
@@ -199,7 +206,7 @@ table(partition)
 R_sparse_mat_time = difftime(end, start)[[1]]
 print(paste(c("leiden time:", R_mat_time, "seconds"), collapse = " "))
 
-## ---- cache=TRUE---------------------------------------------------------
+## ---- cache=TRUE, eval=module-------------------------------------------------
 adjacency_matrix <- rbind(cbind(matrix(round(rbinom(1000000, 1, 0.008)), 1000, 1000),
                                 matrix(round(rbinom(1000000, 1, 0.003)), 1000, 1000),
                                 matrix(round(rbinom(1000000, 1, 0.001)), 1000, 1000)),
@@ -232,7 +239,7 @@ table(partition)
 R_mat_large_time = difftime(end, start)[[1]]
 print(paste(c("leiden time:", R_mat_large_time, "seconds"), collapse = " "))
 
-## ---- cache=TRUE---------------------------------------------------------
+## ---- cache=TRUE, eval=module-------------------------------------------------
 start <- Sys.time()
 for(ii in 1:100){
   adj_mat <- as_adjacency_matrix(G, sparse = TRUE)
@@ -252,7 +259,7 @@ table(partition)
 R_mat_large_time = difftime(end, start)[[1]]
 print(paste(c("leiden time:", R_mat_large_time, "seconds"), collapse = " "))
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 partition_type <- "RBConfigurationVertexPartition"
 initial_membership <- NULL
 weights <- NULL
@@ -330,7 +337,7 @@ timing = difftime(time8, time1)[[1]]
 print(paste(c("total:", timing, "seconds"), collapse = " "))
 partition
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 partition_type <- "RBConfigurationVertexPartition"
 initial_membership <- NULL
 weights <- NULL
@@ -399,7 +406,7 @@ timing = difftime(time8, time1)[[1]]
 print(paste(c("total:", timing, "seconds"), collapse = " "))
 partition
 
-## ------------------------------------------------------------------------
+## ---- eval=module-------------------------------------------------------------
 partition_type <- "RBConfigurationVertexPartition"
 initial_membership <- NULL
 weights <- NULL
@@ -451,7 +458,7 @@ timing = difftime(time8, time1)[[1]]
 print(paste(c("total:", timing, "seconds"), collapse = " "))
 partition
 
-## ---- fig.align = 'center', fig.height = 3, fig.width = 6, fig.keep = 'last'----
+## ---- fig.align = 'center', fig.height = 3, fig.width = 6, fig.keep = 'last', eval=module----
 barplot(c(bash_py_time, py$py_time, reticulate_time, R_graph_time, 
           R_mat_time, R_sparse_mat_time), 
         names = c("Python (shell)", "Python (Rmd)", "Reticulate", "R igraph",
@@ -460,7 +467,7 @@ barplot(c(bash_py_time, py$py_time, reticulate_time, R_graph_time,
         ylab = "time (seconds)", main = "benchmarking 100 computations")
 abline(h=0)
 
-## ---- fig.align = 'center', fig.height = 3, fig.width = 6, fig.keep = 'last'----
+## ---- fig.align = 'center', fig.height = 3, fig.width = 6, fig.keep = 'last', eval=module----
 barplot(c(bash_py_time, py$py_time, reticulate_time, R_graph_time, R_mat_time+R_mat_cast_time, 
           R_sparse_mat_time+R_sparse_mat_cast_time), 
         names = c("Python (shell)", "Python (Rmd)", "Reticulate", "R igraph",
@@ -475,7 +482,7 @@ barplot(c(bash_py_time, py$py_time, reticulate_time, R_graph_time,
         ylab = "time (seconds)", main = "benchmarking 100 computations", add = TRUE)
 abline(h=0)
 
-## ---- fig.align = 'center', fig.height = 3, fig.width = 6, fig.keep = 'last'----
+## ---- fig.align = 'center', fig.height = 3, fig.width = 6, fig.keep = 'last', eval=module----
 R_graph_create_time = difftime(time4, time3)[[1]]
 barplot(c(bash_py_time, py$py_time+reticulate_create_time*100, reticulate_time+reticulate_create_time*100, R_graph_time+R_graph_create_time*100, R_mat_time, 
           R_sparse_mat_time), 
